#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 3/1/21

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.#


from gimpfu import *
import gettext
import os,sys,time 

gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_happy_easter_text_design(customtext, fontname, size):
              
    #Initiates the temporary state
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
	  
    #Create the background
    img = pdb.gimp_image_new(2000, 1280, RGB)
    backLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(backLayer)
    pdb.gimp_image_add_layer(img, backLayer, 0)
    pdb.gimp_context_set_pattern("Grass seamless.jpg")
    pdb.gimp_edit_bucket_fill(backLayer, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    
    #Show process
    pdb.gimp_display_new(img)
	
    #Create the frame
    #g'mic
    #size = 60  
    #density = 5     
    #first_offset = 50 
    #second_offset = 50
    #angle = 45 
    #aliasing = 0.5 
    #shading = 0.1 
    #opacity = 1 
    #colorR = 170 
    #colorG = 255
    #colorB = 0 
    frameLayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Frame", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, frameLayer, 0)
    pdb.gimp_layer_add_alpha(frameLayer)
    pdb.gimp_context_set_foreground((0, 255, 0))
    pdb.gimp_drawable_fill(frameLayer, FILL_FOREGROUND)    
    pdb.plug_in_gmic_qt(img, frameLayer, 1, 0, "-v - -fx_polka_dots 60,5,50,50,45,0.5,0.1,1,170,255,0")    
    pdb.gimp_image_select_rectangle(img, 2, 40, 100, 1920, 1080)		
    pdb.gimp_edit_clear(frameLayer)
    
    #dirt
    dirtLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Dirt", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(dirtLayer)
    pdb.gimp_image_add_layer(img, dirtLayer, 0)
    pdb.gimp_drawable_fill(dirtLayer, FILL_TRANSPARENT)
    pdb.gimp_context_set_pattern("Dirt seamless.jpg")
    pdb.gimp_edit_bucket_fill(dirtLayer, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    
    #Create the text
    dirtLayer = pdb.gimp_image_get_layer_by_name(img, "Dirt")
    textW = size/0.2
    textH = size/0.5
    pdb.gimp_context_set_foreground("Black")
    textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 10, 1, size, PIXELS, fontname)
    pdb.gimp_text_layer_set_justification(textLayer, 2)
    pdb.gimp_text_layer_set_letter_spacing(textLayer, 20)
    pdb.gimp_text_layer_set_line_spacing(textLayer, 0)
        
    #Resize text
    pdb.gimp_layer_scale(textLayer, textW, textH, TRUE)
                
    #Making the text centered	
    textLayer = pdb.gimp_image_get_active_layer(img)
    pdb.gimp_image_set_active_layer(img, textLayer)
    wh = pdb.gimp_drawable_width(textLayer)
    hh = pdb.gimp_drawable_height(textLayer)
    w = pdb.gimp_image_width(img)
    h = pdb.gimp_image_height(img)
    pdb.gimp_image_set_active_layer(img,textLayer)
    centerx=w/2
    centery=h/2
    adw=wh/2
    adh=hh/2
    sw=centerx - adw
    sh=centery - adh		
    pdb.gimp_layer_set_offsets(textLayer, sw, sh)
    pdb.gimp_layer_resize_to_image_size(textLayer)
    
    #Rename the text layer and reduce opacity
    pdb.gimp_item_set_name(textLayer, "Text")

    #Prepare Soil
    pdb.gimp_image_select_item(img, 2, textLayer)
    pdb.gimp_selection_grow(img, 90)
    pdb.gimp_selection_invert(img)
    pdb.gimp_drawable_edit_clear(dirtLayer)
    pdb.gimp_selection_none(img)
     
    #Grass text
    grassText = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Grass Text", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(grassText)
    pdb.gimp_image_add_layer(img, grassText, 0)
    pdb.gimp_context_set_pattern("Grass seamless.jpg")
    pdb.gimp_edit_bucket_fill(grassText, BUCKET_FILL_PATTERN, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    pdb.gimp_image_select_item(img, 2, textLayer)
    pdb.gimp_selection_invert(img)
    pdb.gimp_drawable_edit_clear(grassText)
    pdb.gimp_selection_invert(img)
    pdb.plug_in_sel2path(img, textLayer) 
    pdb.gimp_selection_none(img)
    
    #Add eggs
    eggslayer = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Eggs", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, eggslayer, 0)
    pdb.gimp_layer_add_alpha(eggslayer)
    pdb.gimp_drawable_fill(eggslayer, FILL_TRANSPARENT)
    #Egg 1
    pdb.gimp_context_set_brush("Easter Egg #1")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(-15)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_dynamics("Dynamics Off")  
    pdb.gimp_paintbrush_default(eggslayer, 2, [1592, 364])   
    #Egg 2
    pdb.gimp_context_set_brush("Easter Egg #2")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_angle(-65)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_paintbrush_default(eggslayer, 2, [1000, 428])
    #Egg 3
    pdb.gimp_context_set_brush("Easter Egg #3")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_brush_angle(45)
    pdb.gimp_paintbrush_default(eggslayer, 2, [414, 416])
    #Egg 4
    pdb.gimp_context_set_brush("Easter Egg #4")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_brush_angle(-75)
    pdb.gimp_paintbrush_default(eggslayer, 2, [558, 770])
    #Egg 5
    pdb.gimp_context_set_brush("Easter Egg #5")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_brush_angle(30)
    pdb.gimp_paintbrush_default(eggslayer, 2, [1056, 762])
    #Egg 6
    pdb.gimp_context_set_brush("Easter Egg #6")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_aspect_ratio(0)
    pdb.gimp_context_set_brush_spacing(0.1)
    pdb.gimp_context_set_brush_angle(-45)
    pdb.gimp_paintbrush_default(eggslayer, 2, [1478, 764])
    
    #Add grass sprigs
    sprigsLayer = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Sprigs", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(sprigsLayer)
    pdb.gimp_image_add_layer(img, sprigsLayer, 0)
    pdb.gimp_drawable_fill(sprigsLayer, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((21, 64, 8))
    pdb.gimp_context_set_background((140, 212, 87))
    pdb.gimp_context_set_gradient_fg_bg_rgb()
    pdb.gimp_brushes_set_brush("Grass brush animated 1")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.30)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Random Size/Angel/Color")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors = pdb.gimp_image_get_vectors_by_name(img, _("Selection"))    
    pdb.gimp_drawable_edit_stroke_item(sprigsLayer, vectors)
    #Add more grass   
    pdb.gimp_context_set_foreground((21, 64, 8))
    pdb.gimp_context_set_background((140, 212, 87))
    pdb.gimp_context_set_gradient_fg_bg_rgb()
    pdb.gimp_brushes_set_brush("Grass brush animated 1")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_angle(90)
    pdb.gimp_context_set_brush_spacing(0.30)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Random Size/Angel/Color")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors = pdb.gimp_image_get_vectors_by_name(img, _("Selection")) 
    pdb.gimp_drawable_edit_stroke_item(sprigsLayer, vectors)
    pdb.gimp_drawable_edit_stroke_item(grassText, vectors)
    
    #Add grass sprigs 2
    pdb.gimp_image_select_item(img, 2, dirtLayer)
    pdb.plug_in_sel2path(img, dirtLayer) 
    pdb.gimp_selection_none(img) 
    sprigsLayer2 = pdb.gimp_layer_new(img, img.width, img.height, RGB_IMAGE, "Sprigs #2", 100, LAYER_MODE_NORMAL)
    pdb.gimp_layer_add_alpha(sprigsLayer2)
    pdb.gimp_image_add_layer(img, sprigsLayer2, 3)
    pdb.gimp_drawable_fill(sprigsLayer2, FILL_TRANSPARENT)
    pdb.gimp_context_set_foreground((21, 64, 8))
    pdb.gimp_context_set_background((140, 212, 87))
    pdb.gimp_context_set_gradient_fg_bg_rgb()
    pdb.gimp_brushes_set_brush("Grass brush animated 1")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_angle(0)
    pdb.gimp_context_set_brush_spacing(0.30)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Random Size/Angel/Color")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors2 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #1'))   
    pdb.gimp_drawable_edit_stroke_item(sprigsLayer2, vectors2)
    #Add more grass   
    pdb.gimp_context_set_foreground((21, 64, 8))
    pdb.gimp_context_set_background((140, 212, 87))
    pdb.gimp_context_set_gradient_fg_bg_rgb()
    pdb.gimp_brushes_set_brush("Grass brush animated 1")
    pdb.gimp_context_set_brush_size(100)
    pdb.gimp_context_set_brush_angle(90)
    pdb.gimp_context_set_brush_spacing(0.30)
    pdb.gimp_context_set_brush_default_hardness()
    pdb.gimp_context_set_dynamics("Random Size/Angel/Color")
    pdb.gimp_context_set_stroke_method (STROKE_PAINT_METHOD)
    vectors2 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #1')) 
    pdb.gimp_drawable_edit_stroke_item(sprigsLayer2, vectors2)
    pdb.gimp_drawable_edit_stroke_item(sprigsLayer2, vectors2)   
    
    non_empty = pdb.gimp_edit_copy(eggslayer)
    eggsLayer2 = pdb.gimp_layer_new(img, img.width, img.height, RGBA_IMAGE, "Eggs copy", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_add_layer(img, eggsLayer2, 1)
    pdb.gimp_layer_add_alpha(eggsLayer2)
    pdb.gimp_drawable_fill(eggsLayer2, FILL_TRANSPARENT)
    eggsLayer2 = pdb.gimp_edit_paste(eggsLayer2, FALSE)
    pdb.gimp_floating_sel_anchor(eggsLayer2) 
    eggsLayer2 = pdb.gimp_image_get_layer_by_name(img, "Eggs copy")
    
    eggsLayer2 = pdb.gimp_item_transform_flip_simple(eggsLayer2, 
                                         ORIENTATION_HORIZONTAL,   #flip_type
                                                           TRUE,   #auto_center
                                                              0)   #axis
    eggsLayer2 = pdb.gimp_item_transform_flip_simple(eggsLayer2, 
                                          ORIENTATION_VERTICAL,   #flip_type
                                                          TRUE,   #auto_center
                                                             0)   #axis
    
    pdb.gimp_drawable_hue_saturation(eggsLayer2, 
                                              0,  #hue_range - hue_range_all
                                              0,  #hue_offset
                                            -35,  #lightness
                                            100,  #saturation
                                              0)  #overlap
      
    #Eggs drop shadow
    pdb.python_layerfx_drop_shadow(img, eggslayer, 
                                       (0, 0, 0),   #color
                                               75,   #opacity
                                                0,   #contou - linear
                                                0,   #noise 
                                                3,   #mode for multiply 
                                                0,   #spread 
                                                8,   #size 
                                              110,   #offset_angle 
                                               10,   #offset_distance 
                                             TRUE,   #knockout 
                                             TRUE)   #merge
                                             
    #Eggs copy drop shadow
    pdb.python_layerfx_drop_shadow(img, eggsLayer2, 
                                         (0, 0, 0),   #color
                                                75,   #opacity
                                                 0,   #contou - linear
                                                 0,   #noise 
                                                 3,   #mode for multiply 
                                                 0,   #spread 
                                                 8,   #size 
                                               110,   #offset_angle 
                                                10,   #offset_distance 
                                              TRUE,   #knockout 
                                              TRUE)   #merge                                         
    
    #Sprigs drop shadow
    pdb.python_layerfx_drop_shadow(img, sprigsLayer, 
                                          (0, 0, 0),   #color
                                                100,   #opacity
                                                  0,   #contou - linear
                                                  0,   #noise 
                                                  3,   #mode for multiply 
                                                  5,   #spread 
                                                  7,   #size 
                                                120,   #offset_angle 
                                                 10,   #offset_distance 
                                               TRUE,   #knockout 
                                               TRUE)   #merge
    
    #Sprigs drop shadow
    pdb.python_layerfx_drop_shadow(img, sprigsLayer2, 
                                           (0, 0, 0),   #color
                                                 100,   #opacity
                                                   0,   #contou - linear
                                                   0,   #noise 
                                                   3,   #mode for multiply 
                                                   5,   #spread 
                                                   7,   #size 
                                                 120,   #offset_angle 
                                                  10,   #offset_distance 
                                                TRUE,   #knockout 
                                                TRUE)   #merge
    
    backLayer = pdb.gimp_image_get_layer_by_name(img, "Background")
    pdb.gimp_image_set_active_layer(img, backLayer)
	
    #Set gimp to default
    pdb.gimp_context_set_defaults()
    pdb.gimp_context_set_default_colors()
   	
register(
    "pm_create_happy_easter_text_design",
    "Create a Happy Easter Text Design",
    "Create a Happy Easter Text Design",
    "Pocholo",
    "Pocholo",
    "2021",
    "Create a Happy Easter Text Design",
    "",
    [
    (PF_TEXT, "customtext", "Text string", 'HAPPY\nEASTER'),
    (PF_FONT, "font", "Font name", "Mousou Record__G"),
    (PF_SPINNER, "size", "Text size", 350, (350, 350, 1)),    
    ],
    [],
    pm_create_happy_easter_text_design, menu="<Image>/Pocholo-scripts/Create a Happy Easter Text Design",
    domain=("gimp20", gimp.locale_directory))
main()						   				